summaryrefslogtreecommitdiff
path: root/jstests/auth/lib/commands_lib.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/auth/lib/commands_lib.js')
-rw-r--r--jstests/auth/lib/commands_lib.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/auth/lib/commands_lib.js b/jstests/auth/lib/commands_lib.js
index 170223762b4..1d60c7aa308 100644
--- a/jstests/auth/lib/commands_lib.js
+++ b/jstests/auth/lib/commands_lib.js
@@ -6629,12 +6629,12 @@ export const authCommandsLib = {
]
},
{
// Test that only clusterManager has permission to run $telemetry
testname: "testTelemetryReadPrivilege",
- command: {aggregate: 1, pipeline: [{$telemetry: {}}], cursor: {}},
+ command: {aggregate: 1, pipeline: [{$queryStats: {}}], cursor: {}},
skipSharded: false,
skipTest: (conn) => {
- return !TestData.setParameters.featureFlagTelemetry;
+ return !TestData.setParameters.featureFlagQueryStats;
},
testcases: [{runOnDb: adminDbName, roles: roles_clusterManager}]
},
@@ -6629,12 +6629,12 @@ export const authCommandsLib = {
},
{
- // Test that only clusterManager has permission to run $telemetry
+ // Test that only clusterManager has permission to run $queryStats
testname: "testTelemetryReadPrivilege",